Providers — Kivy v1.0.1-dev documentation

# Providers

- Native support of HID input from linux kernel
- Native support of Wacom tablet from linuxwacom driver
- Native support of MultitouchSupport framework for MacBook (MaxOSX platform)
- Mouse provider implementation
- Native support of Multitouch device on Linux, using libmtdev.
- Auto Create Input Provider Config Entry for Available MT Hardware (linux only).
- TUIO input provider implementation
- Common definitions for Windows provider
- Support of WM_PEN message (Window platform)
- Support of WM_TOUCH message (Window platform)